@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::MakeMaker::Fallback; # git description: v0.019-8-gd573830
+package Dist::Zilla::Plugin::MakeMaker::Fallback; # git description: v0.020-4-gee9a72d
 # ABSTRACT: Generate a Makefile.PL containing a warning for legacy users
 # KEYWORDS: plugin installer MakeMaker Makefile.PL toolchain legacy ancient backcompat
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.020';
+our $VERSION = '0.021';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::MakeMaker::Awesome' => { -version => '0.15' };
@@ -213,14 +213,6 @@ __PACKAGE__->meta->make_immutable;
 #pod weed out test issues that only manifest under these conditions (for example:
 #pod bad test count, conditional module loading).
 #pod
-#pod =head1 SUPPORT
-#pod
-#pod =for stopwords irc
-#pod
-#pod Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-MakeMaker-Fallback>
-#pod (or L<bug-Dist-Zilla-Plugin-MakeMaker-Fallback@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-MakeMaker-Fallback@rt.cpan.org>).
-#pod I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-#pod
 #pod =head1 ACKNOWLEDGEMENTS
 #pod
 #pod =for stopwords Peter Rabbitson ribasushi Matt Trout mst
@@ -253,7 +245,7 @@ Dist::Zilla::Plugin::MakeMaker::Fallback - Generate a Makefile.PL containing a w
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -319,14 +311,6 @@ testing variables B<unset> (C<AUTHOR_TESTING>, C<RELEASE_TESTING>). This is to
 weed out test issues that only manifest under these conditions (for example:
 bad test count, conditional module loading).
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-MakeMaker-Fallback>
-(or L<bug-Dist-Zilla-Plugin-MakeMaker-Fallback@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-MakeMaker-Fallback@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 ACKNOWLEDGEMENTS
 
 =for stopwords Peter Rabbitson ribasushi Matt Trout mst
@@ -358,6 +342,19 @@ L<Dist::Zilla::Plugin::ModuleBuildTiny::Fallback>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-MakeMaker-Fallback>
+(or L<bug-Dist-Zilla-Plugin-MakeMaker-Fallback@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-MakeMaker-Fallback@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#distzilla.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
